@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 use Moo;
 use strictures 2;
@@ -85,6 +85,7 @@ sub BUILD {
             $self->_filter_and_forward($event);
         }
     );
+
     my $input_name = $self->input;
     $self->_msg_channel->send(\$input_name);
 
@@ -129,7 +130,6 @@ sub send_it ($self, $event) {
 
 
 sub delay_send ($self, $delay_time, $event) {
-    _log("Event: @$event, Delay: $delay_time") if $self->verbose;
     $self->loop->add(
         IO::Async::Timer::Countdown->new(
             delay     => $delay_time,
@@ -164,7 +164,7 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
@@ -273,7 +273,7 @@ Barrett AKA fuzzix).
 
 =head1 SEE ALSO
 
-The F<eg/*.pl> example program(s)
+The F<eg/*.pl> example programs
 
 L<Future::AsyncAwait>
 
